==> core-io-1.7.7-sources.jar: com/couchbase/client/deps/io/netty/handler/codec/http/HttpRequest.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.couchbase.client.deps.io.netty.handler.codec.http;

/**
 * An HTTP request.
 *
 * <h3>Accessing Query Parameters and Cookie</h3>
 * <p>
 * Unlike the Servlet API, a query string is constructed and decomposed by
 * {@link QueryStringEncoder} and {@link QueryStringDecoder}.
 *
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.Cookie} support is also provided
 * separately via {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieDecoder},
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieDecoder},
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieEncoder},
 * and {@link @com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieEncoder}.
 *
 * @see HttpResponse
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieDecoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieDecoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieEncoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieEncoder
 */
public interface HttpRequest extends HttpMessage {

    /**
     * Returns the {@link HttpMethod} of this {@link HttpRequest}.
     *
     * @return The {@link HttpMethod} of this {@link HttpRequest}
     */
    HttpMethod getMethod();

    /**
     * Set the {@link HttpMethod} of this {@link HttpRequest}.
     */
    HttpRequest setMethod(HttpMethod method);

    /**
     * Returns the requested URI (or alternatively, path)
     *
     * @return The URI being requested
     */
    String getUri();

    /**
     *  Set the requested URI (or alternatively, path)
     */
    HttpRequest setUri(String uri);

    @Override
    HttpRequest setProtocolVersion(HttpVersion version);
}

==> core-io-1.7.16-sources.jar: com/couchbase/client/deps/io/netty/handler/codec/http/HttpRequest.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.couchbase.client.deps.io.netty.handler.codec.http;

/**
 * An HTTP request.
 *
 * <h3>Accessing Query Parameters and Cookie</h3>
 * <p>
 * Unlike the Servlet API, a query string is constructed and decomposed by
 * {@link QueryStringEncoder} and {@link QueryStringDecoder}.
 *
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.Cookie} support is also provided
 * separately via {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieDecoder},
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieDecoder},
 * {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieEncoder},
 * and {@link com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieEncoder}.
 *
 * @see HttpResponse
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieDecoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieDecoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ServerCookieEncoder
 * @see com.couchbase.client.deps.io.netty.handler.codec.http.cookie.ClientCookieEncoder
 */
public interface HttpRequest extends HttpMessage {

    /**
     * @deprecated Use {@link #method()} instead.
     */
    @Deprecated
    HttpMethod getMethod();

    /**
     * Returns the {@link HttpMethod} of this {@link HttpRequest}.
     *
     * @return The {@link HttpMethod} of this {@link HttpRequest}
     */
    HttpMethod method();

    /**
     * Set the {@link HttpMethod} of this {@link HttpRequest}.
     */
    HttpRequest setMethod(HttpMethod method);

    /**
     * @deprecated Use {@link #uri()} instead.
     */
    @Deprecated
    String getUri();

    /**
     * Returns the requested URI (or alternatively, path)
     *
     * @return The URI being requested
     */
    String uri();

    /**
     *  Set the requested URI (or alternatively, path)
     */
    HttpRequest setUri(String uri);

    @Override
    HttpRequest setProtocolVersion(HttpVersion version);
}
